
var todoDB = (function() {
  var tDB = {};
  var datastore = null;


        /**
         Kode som omhandler tilkoblingen til databasen.
         */
        tDB.open = function(callback) {
          // Databasen versjon.
          var version = 1;
          // Tilkobling til databasen "todos"
          var request = indexedDB.open('todos', version);

          // Dersom basen trengs å oppgraders:
          request.onupgradeneeded = function(e) {
            var db = e.target.result;

            e.target.transaction.onerror = tDB.onerror;

            // Sørger for at den gamle objectStoren blir slettet. Dette fjerner ikke informasjonen fra den.
            if (db.objectStoreNames.contains('todo')) {
              db.deleteObjectStore('todo');
            }
            // Oppretter ny objectStore.
            var store = db.createObjectStore('todo', {
              keyPath: 'timestamp'
            });
          };

          //Kode for suksessful tilkobling.
          request.onsuccess = function(e) {
            // Get a reference to the DB.
            datastore = e.target.result;
            // Execute the callback.
            callback();
          };

          // Dersom noe går galt når man forsøker å åpne objectStore
          request.onerror = tDB.onerror;
        };

        //metoder for å gjøre ting med databasen

               /**
               Kode for å hente all informasjonen i ObjectStoren 'todo'
               */

              tDB.fetchTodos = function(callback) {
                var db = datastore;
                var transaction = db.transaction(['todo'], 'readwrite');
                var objStore = transaction.objectStore('todo');

                var keyRange = IDBKeyRange.lowerBound(0);
                var cursorRequest = objStore.openCursor(keyRange);

                var todos = [];

                transaction.oncomplete = function(e) {
                  // Execute the callback function.
                  callback(todos);
                };

                cursorRequest.onsuccess = function(e) {
                  var result = e.target.result;

                  if (!!result == false) {
                    return;
                  }

                  todos.push(result.value);

                  result.continue();
                };

                cursorRequest.onerror = tDB.onerror;
              };



                    /**
                     Kode for å legge til et gjøremål
                     */
                    tDB.createTodo = function(text, callback) {
                      // Get a reference to the db.
                      var db = datastore;
                      // Start transaksjonen
                      var transaction = db.transaction(['todo'], 'readwrite');
                      // Hent ObjectStoren
                      var objStore = transaction.objectStore('todo');
                      // Lag en timestamp, som unik nøkkel for gjøremålet.
                      var timestamp = new Date().getTime();
                      //Opprett databaseobjektet for gjøremålet
                      var todo = {
                        'text': text,
                        'timestamp': timestamp
                      };
                      // Request at gjørmålet blir lagret i databasen.
                      var request = objStore.put(todo);
                      // Dersom det går bra....
                      request.onsuccess = function(e) {
                        // Execute the callback function.
                        callback(todo);
                      };
                      // Hvis noe går galt...
                      request.onerror = tDB.onerror;
                    };


                          /**
                           * Kode for å slette gjøremål fra databasen (checkboxen blir utløst).
                           Iden som forteller hvilket gjøremål som skal slettes kommer fra koden bak checkboxen. Resten av koden tilsvarer funksjonen over, men sletter istedenfor og legge inn.
                           */
                          tDB.deleteTodo = function(id, callback) {
                            var db = datastore;
                            var transaction = db.transaction(['todo'], 'readwrite');
                            var objStore = transaction.objectStore('todo');
                            var request = objStore.delete(id);
                            request.onsuccess = function(e) {
                              callback();
                            }
                            request.onerror = function(e) {
                              console.log(e);
                            }
                          };
  //eksporter tDB
  return tDB;
}());
